package it.unibas.appuntamenti.modello;

public class Agenda {
    
    private String utente;
    private java.util.HashMap giorni = new java.util.HashMap();
    
    public java.lang.String getUtente() {
        return utente;
    }
    
    public void setUtente(java.lang.String utente) {
        this.utente = utente;
    }
    
    public void addGiorno(String data, Giorno giorno) {
        this.giorni.put(giorno.toShortString(), giorno);
    }
    
    public void removeGiorno(String data) {
        this.giorni.remove(data);
    }
    
    public Giorno getGiorno(String data) {
        return (Giorno)(this.giorni.get(data));
    }
    
    public int getNumeroGiorni() {
        return this.giorni.size();
    }
    
    public static Agenda carica(String nomeFile) throws java.io.IOException {
        Agenda agenda = new Agenda();
        java.io.BufferedReader flusso = null;
        try {
            java.io.FileReader fileReader = new java.io.FileReader(nomeFile);
            flusso = new java.io.BufferedReader(fileReader);
            caricaDati(agenda, flusso);
       } finally {
            try {
                if (flusso != null) {
                    flusso.close();
                }
            } catch (java.io.IOException ioe) {}
        }
        return agenda;
    }
    
    private static void caricaDati(Agenda agenda, java.io.BufferedReader flusso) throws java.io.IOException {
        String lineaUtente = flusso.readLine();
        if (lineaUtente != null) {
            agenda.utente = estraiUtente(lineaUtente);
            caricaGiorni(agenda, flusso);
        }
    }
    
    private static String estraiUtente(String lineaUtente) {
        int indice = lineaUtente.indexOf(":") + 1;
        return lineaUtente.substring(indice).trim();
    }
    
    private static void caricaGiorni(Agenda agenda, java.io.BufferedReader flusso) throws java.io.IOException {
        String lineaGiorno;
        while ((lineaGiorno = flusso.readLine()) != null) {
            Giorno giorno = estraiGiorno(lineaGiorno);
            caricaImpegni(agenda, giorno, flusso);
        }
    }
    
    private static Giorno estraiGiorno(String lineaGiorno) {
        int indice = lineaGiorno.indexOf(":") + 1;
        int giornata = Integer.parseInt(lineaGiorno.substring(indice + 1, indice + 3));
        int mese = Integer.parseInt(lineaGiorno.substring(indice + 4, indice + 6));
        int anno = 2000 + Integer.parseInt(lineaGiorno.substring(indice + 7, indice + 9));
        Giorno giorno = new Giorno(giornata, mese, anno);
        return giorno;
    }
    
    private static void caricaImpegni(Agenda agenda, Giorno giorno, java.io.BufferedReader flusso) throws java.io.IOException {
        String lineaImpegno;
        while ((lineaImpegno = flusso.readLine()) != null){
            if (lineaImpegno.indexOf("----") == -1) {
                Impegno impegno = estraiImpegno(lineaImpegno);
                giorno.addImpegno(impegno);
            } else {
                agenda.addGiorno(giorno.toShortString(), giorno);
                return;
            }
        }
    }
    
    private static Impegno estraiImpegno(String lineaImpegno) {
        java.util.StringTokenizer tokenizer = new java.util.StringTokenizer(lineaImpegno, "|");
        String tipo = tokenizer.nextToken().trim();
        Impegno impegno;
        if (tipo.equals("riunione")) {
            impegno = estraiRiunione(tokenizer);
        } else {
            impegno = estraiLezione(tokenizer);
        }
        return impegno;
    }
    
    private static Impegno estraiRiunione(java.util.StringTokenizer tokenizer) {
        String stringaOrario = tokenizer.nextToken();
        Orario orario = estraiOrario(stringaOrario);
        String descrizione = tokenizer.nextToken().trim();
        String luogo = tokenizer.nextToken().trim();
        String partecipanti = tokenizer.nextToken().trim();
        String note = tokenizer.nextToken().trim();
        Riunione riunione = new Riunione(descrizione, partecipanti, luogo, note, orario);
        return riunione;
    }
    
    private static Impegno estraiLezione(java.util.StringTokenizer tokenizer) {
        String stringaOrario = tokenizer.nextToken();
        Orario orario = estraiOrario(stringaOrario);
        String corso = tokenizer.nextToken().trim();
        String luogo = tokenizer.nextToken().trim();
        String note = tokenizer.nextToken().trim();
        Lezione lezione = new Lezione(corso, luogo, note, orario);
        return lezione;
    }
    
    private static Orario estraiOrario(String stringaOrario) {
        int indice = stringaOrario.indexOf(":");
        int ore = Integer.parseInt(stringaOrario.substring(indice - 2, indice).trim());
        int minuti = Integer.parseInt(stringaOrario.substring(indice + 1, indice + 3).trim());
        Orario orario = new Orario(ore, minuti);
        return orario;
    }
    
    public void salva(String nomeFile) throws java.io.IOException {
        java.io.PrintWriter flusso = null;
        try {
            java.io.FileWriter fileWriter = new java.io.FileWriter(nomeFile);
            flusso = new java.io.PrintWriter(fileWriter);
            flusso.println("Utente: " + this.utente);
            salvaGiorni(flusso);
        } finally {
            if (flusso != null) {
                flusso.close();
            }
        }
    }
    
    private void salvaGiorni(java.io.PrintWriter flusso) {
        java.util.Collection giorni = this.giorni.values();
        java.util.List listaGiorni = ordina(giorni);
        for (int i = 0; i < listaGiorni.size(); i++) {
            Giorno giornoIesimo = (Giorno)listaGiorni.get(i);
            flusso.println("Giorno: " + giornoIesimo.toShortString());
            salvaImpegni(giornoIesimo, flusso);
        }
    }
    
    private java.util.List ordina(java.util.Collection coll) {
        java.util.List lista = new java.util.ArrayList(coll);
        java.util.Collections.sort(lista);
        return lista;
    }
    
    private void salvaImpegni(Giorno giorno, java.io.PrintWriter flusso) {
        java.util.List listaImpegni = giorno.getListaImpegni();
        for (int i = 0; i < listaImpegni.size(); i++){
            Impegno impegnoIesimo = (Impegno)listaImpegni.get(i);
            flusso.println(impegnoIesimo.saveString());
        }
        flusso.println("-----");
    }
    
    public String toString() {
        StringBuffer stringa = new StringBuffer();
        stringa.append("Utente: " + this.utente + "\n");
        java.util.Collection giorni = this.giorni.values();
        java.util.List listaGiorni = ordina(giorni);
        for (int i = 0; i < listaGiorni.size(); i++) {
            Object giornoIesimo = listaGiorni.get(i);
            stringa.append(giornoIesimo);
        }
        return stringa.toString();
    }
    
}
