package it.unibas.appuntamenti.modello;

public class Giorno implements Comparable {
    
    private java.util.GregorianCalendar calendar;
    private java.util.List listaImpegni = new java.util.LinkedList();
    
    public Giorno(int gg, int mese, int anno) {
        if (gg < 0 || gg > 31) {
            throw new IllegalArgumentException("Valore scorretto del giorno: " + gg);
        }
        if (mese < 1 || mese > 12) {
            throw new IllegalArgumentException("Valore scorretto del mese: " + mese);
        }
        if (anno < 0) {
            throw new IllegalArgumentException("Valore scorretto dell'anno: " + anno);
        }
        this.calendar = new java.util.GregorianCalendar(anno, mese - 1, gg);
    }
    
    public int getNumGiorno() {
        return this.calendar.get(java.util.Calendar.DAY_OF_MONTH);
    }
    
    public int getMese() {
        return this.calendar.get(java.util.Calendar.MONTH);
    }
    
    public int getAnno() {
        return this.calendar.get(java.util.Calendar.YEAR);
    }
    
    public int getGiornoSettimana() {
        return this.calendar.get(java.util.Calendar.DAY_OF_WEEK);
    }
    
    public String toShortString() {
        java.util.Date date = this.calendar.getTime();
        java.text.DateFormat dateFormat =
        java.text.DateFormat.getDateInstance(java.text.DateFormat.SHORT);
        return dateFormat.format(date);
    }
    
    public String toString() {
        java.util.Date date = this.calendar.getTime();
        java.text.DateFormat dateFormat =
        java.text.DateFormat.getDateInstance(java.text.DateFormat.FULL);
        String stringaData = dateFormat.format(date);
        String separatore = "-------------------------";
        return stringaData + "\n" + separatore + "\n" + stringaImpegni() + separatore + "\n";
    }
    
    public boolean equals(Giorno giorno) {
        return this.toShortString().equals(giorno.toShortString());
    }
    
    public void addImpegno(Impegno impegno) {
        this.listaImpegni.add(impegno);
    }
    
    public java.util.List getListaImpegni() {
        return this.listaImpegni;
    }
    
    public int getNumeroImpegni() {
        return this.listaImpegni.size();
    }
        
    public Impegno getImpegno(int i) {
        if (i < 0 || i >= this.getNumeroImpegni()) {
            throw new IndexOutOfBoundsException("Posizione inesistente");
        }
        return (Impegno)(this.listaImpegni.get(i));
    }
    
    public void removeImpegno(int i) {
        if (i < 0 || i >= this.getNumeroImpegni()) {
            throw new IndexOutOfBoundsException("Posizione inesistente");
        }
        this.listaImpegni.remove(i);
    }
    
    public void ordinaImpegni() {
        java.util.Collections.sort(this.listaImpegni);
    }
    
    public String stringaImpegni() {
        ordinaImpegni();
        StringBuffer stringaImpegni = new StringBuffer();
        for (int i = 0; i < this.listaImpegni.size(); i++) {
            Object impegnoIesimo = this.listaImpegni.get(i);
            stringaImpegni.append(i + ". - " + impegnoIesimo.toString());
            stringaImpegni.append("\n");
        }
        return stringaImpegni.toString();
    }
    
    public int compareTo(Object giorno) {
        java.util.Date questaData = this.calendar.getTime();
        java.util.Date altraData = ((Giorno)giorno).calendar.getTime();
        return questaData.compareTo(altraData);
    }
    
    public static String costruisciStringaData(int gg, int mese, int anno) {
        String padGg = "";
        String padMese = "";
        String stringaAnno = new String(anno + "").substring(2);
        if (gg < 10) {
            padGg = "0";
        }
        if (mese < 10) {
            padMese = "0";
        }
        return padGg + gg + "/" + padMese + mese + "/" + stringaAnno;
    }
}


