package it.unibas.appuntamenti.test;

import junit.framework.*;
import it.unibas.appuntamenti.modello.*;

public class TestAgenda extends TestCase {

    private Agenda agenda;
    private String prefisso1 = Utilita.percorso;
    private String nomeFile1 = Utilita.nomeFile1;
    private String nomeFile2 = Utilita.nomeFile2;
    private String nomeFile3 = Utilita.nomeFile3;
    private String nomeFileS1 = Utilita.nomeFileS1;
    private String nomeFileS2 = Utilita.nomeFileS2;

    public void setUp() {
        agenda = new Agenda();
    }

    public void testCarica1() throws Exception {
        Agenda agenda = Agenda.carica(nomeFile1);
        verificaAgenda1(agenda);
    }

    public void verificaAgenda1(Agenda agenda) {
        Assert.assertTrue("utente", agenda.getUtente().equals("Mario"));
        Assert.assertTrue("giorni", agenda.getNumeroGiorni() == 3);
        Giorno giorno1 = agenda.getGiorno("25/05/04");
        Assert.assertTrue("25/05/04", giorno1 != null);
        Assert.assertTrue("1. impegni", giorno1.getNumeroImpegni() == 2);
        verificaRiunione(giorno1.getImpegno(0), "13:30", "riunione di prova", "Universit", "tizio e caio", "*");
        verificaLezione(giorno1.getImpegno(1), "15:00", "Prog. Oggetti", "Aula 1", "*");
        Giorno giorno2 = agenda.getGiorno("27/05/04");
        Assert.assertTrue("27/05/04", giorno2 != null);
        Assert.assertTrue("2. impegni", giorno2.getNumeroImpegni() == 3);
        verificaRiunione(giorno2.getImpegno(0), " 8:30", "riunione n. 2", "Universit", "tizio", "*");
        verificaLezione(giorno2.getImpegno(1), " 9:00", "Prog. Oggetti II", "Aula 1", "*");
        verificaLezione(giorno2.getImpegno(2), "15:00", "Sviluppo Web", "Aula Magna", "*");
        Giorno giorno3 = agenda.getGiorno("29/05/04");
        Assert.assertTrue("29/05/04", giorno3 != null);
        Assert.assertTrue("3. impegni", giorno3.getNumeroImpegni() == 1);
        verificaRiunione(giorno3.getImpegno(0), "13:30", "riunione di prova", "Universit", "tizio e caio", "*");
        Giorno giorno4 = agenda.getGiorno("30/05/04");
        Assert.assertTrue("null", giorno4 == null);
    }

    public void testCarica2() throws Exception {
        Agenda agenda = Agenda.carica(nomeFile2);
        Assert.assertTrue("utente", agenda.getUtente().equals("Franco Rossi"));
        Assert.assertTrue("giorni", agenda.getNumeroGiorni() == 3);
        Giorno giorno1 = agenda.getGiorno("01/05/04");
        Assert.assertTrue("01/05/04", giorno1 != null);
        Assert.assertTrue("1. impegni", giorno1.getNumeroImpegni() == 2);
        verificaRiunione(giorno1.getImpegno(0), "13:30", "CIP", "Universit", "tizio e caio", "*");
        verificaLezione(giorno1.getImpegno(1), "15:00", "Prog. Oggetti", "Aula 1", "*");
        Giorno giorno2 = agenda.getGiorno("22/05/04");
        Assert.assertTrue("22/05/04", giorno2 != null);
        Assert.assertTrue("2. impegni", giorno2.getNumeroImpegni() == 0);
        Giorno giorno3 = agenda.getGiorno("30/05/04");
        Assert.assertTrue("30/05/04", giorno3 != null);
        Assert.assertTrue("3. impegni", giorno3.getNumeroImpegni() == 1);
        verificaRiunione(giorno3.getImpegno(0), "13:30", "riunione di prova", "Universit", "tizio e caio", "*");
        Giorno giorno4 = agenda.getGiorno("29/05/04");
        Assert.assertTrue("null", giorno4 == null);
    }

    public void testCarica3() throws Exception {
        Agenda agenda = Agenda.carica(nomeFile3);
        Assert.assertTrue("utente", agenda.getUtente().equals("Mario"));
        Assert.assertTrue("giorni", agenda.getNumeroGiorni() == 0);
        Giorno giorno1 = agenda.getGiorno("01/05/04");
        Assert.assertTrue("01/05/04", giorno1 == null);
    }

    private void verificaRiunione (Impegno impegno, String orario, String descrizione,
                                   String luogo, String partecipanti, String note) {
        Assert.assertTrue("orario", ((Riunione)impegno).getOrario().toString().equals(orario));
        Assert.assertTrue("descr", ((Riunione)impegno).getDescrizione().equals(descrizione));
        Assert.assertTrue("luogo", ((Riunione)impegno).getLuogo().equals(luogo));
        Assert.assertTrue("partec", ((Riunione)impegno).getPartecipanti().equals(partecipanti));
        Assert.assertTrue("note", ((Riunione)impegno).getNote().equals(note));
    }

    private void verificaLezione (Impegno impegno, String orario, String corso,
                                   String luogo, String note) {
        Assert.assertTrue("orario", ((Lezione)impegno).getOrario().toString().equals(orario));
        Assert.assertTrue("corso", ((Lezione)impegno).getCorso().equals(corso));
        Assert.assertTrue("luogo", ((Lezione)impegno).getLuogo().equals(luogo));
        Assert.assertTrue("note", ((Lezione)impegno).getNote().equals(note));
    }

    public void testSalva1() throws Exception {
        agenda = Agenda.carica(nomeFile1);
        agenda.salva(nomeFileS1);
        Agenda agenda2 = Agenda.carica(nomeFileS1);
        verificaAgenda1(agenda2);
    }

    public void testSalva2() throws Exception {
        agenda.setUtente("Mario");
        agenda.salva(nomeFileS2);
        Agenda agenda2 = Agenda.carica(nomeFileS2);
        Assert.assertTrue("utente", agenda.getUtente().equals("Mario"));
        Assert.assertTrue("giorni", agenda.getNumeroGiorni() == 0);
    }

}
